.. _partitioner_module:

:mod:`kazoo.recipe.partitioner`
-------------------------------

.. automodule:: kazoo.recipe.partitioner

Public API
++++++++++

    .. autoclass:: SetPartitioner
        :members:

        .. automethod:: __init__

    .. autoclass:: PartitionState
